@@ -7,7 +7,6 @@
 ## multicolumn: each child analyzes a different column
 ## arbitrary: children are not related to each other in any systematic fashion.
 
-
 ## null is ok here.
 check_ok_label <- function(lbl, multi_ok = FALSE) {
   if (length(lbl) == 0) {
@@ -42,19 +41,12 @@ valid_lbl_pos <- c("default", "visible", "hidden", "topleft")
   ret
 }
 
-
 setOldClass("expression")
 setClassUnion("SubsetDef", c("expression", "logical", "integer", "numeric"))
 
-
-
 setClassUnion("integerOrNULL", c("NULL", "integer"))
 setClassUnion("characterOrNULL", c("NULL", "character"))
 
-
-
-
-
 ## should XXX [splits, s_values, sval_labels, subset(?)] be a data.frame?
 setClass("TreePos", representation(
   splits = "list",
@@ -68,8 +60,6 @@ validity = function(object) {
 }
 )
 
-
-
 setClassUnion("functionOrNULL", c("NULL", "function"))
 setClassUnion("listOrNULL", c("NULL", "list"))
 ## TODO (?) make "list" more specific, e.g FormatList, or FunctionList?
@@ -127,7 +117,6 @@ LevelComboSplitValue <- function(val, extr, combolevels, label = val) {
   )
 }
 
-
 setClass("Split",
   contains = "VIRTUAL",
   representation(
@@ -154,15 +143,14 @@ setClass("Split",
   )
 )
 
-
 setClass("CustomizableSplit",
   contains = "Split",
   representation(split_fun = "functionOrNULL")
 )
 
+#' @author Gabriel Becker
 #' @exportClass VarLevelSplit
 #' @rdname VarLevelSplit
-#' @author Gabriel Becker
 setClass("VarLevelSplit",
   contains = "CustomizableSplit",
   representation(
@@ -173,8 +161,10 @@ setClass("VarLevelSplit",
 #' Split on levels within a variable
 #'
 #' @inheritParams lyt_args
-#' @return a \code{VarLevelSplit} object.
 #' @inheritParams constr_args
+#'
+#' @return a `VarLevelSplit` object.
+#'
 #' @export
 VarLevelSplit <- function(var,
                           split_label,
@@ -225,7 +215,6 @@ VarLevelSplit <- function(var,
   )
 }
 
-
 setClass("AllSplit", contains = "Split")
 
 AllSplit <- function(split_label = "",
@@ -302,10 +291,11 @@ setClass("ManualSplit",
 #' @inheritParams lyt_args
 #' @inheritParams constr_args
 #' @inheritParams gen_args
-#' @param levels character. Levels of the split (i.e. the children of the manual
-#'   split)
+#' @param levels (`character`)\cr levels of the split (i.e. the children of the manual split).
+#'
+#' @return A `ManualSplit` object.
+#'
 #' @author Gabriel Becker
-#' @return A \code{ManualSplit} object.
 #' @export
 ManualSplit <- function(levels, label, name = "manual",
                         extra_args = list(),
@@ -335,7 +325,6 @@ ManualSplit <- function(levels, label, name = "manual",
   )
 }
 
-
 ## splits across which variables are being analynzed
 setClass("MultiVarSplit",
   contains = "CustomizableSplit", ## "Split",
@@ -350,7 +339,6 @@ setClass("MultiVarSplit",
   }
 )
 
-
 .make_suffix_vec <- function(n) {
   c(
     "",
@@ -377,12 +365,15 @@ setClass("MultiVarSplit",
   }
   ret
 }
+
 #' Split between two or more different variables
 #'
 #' @inheritParams lyt_args
 #' @inheritParams constr_args
+#'
+#' @return A `MultiVarSplit` object.
+#'
 #' @author Gabriel Becker
-#' @return A \code{MultiVarSplit} object.
 #' @export
 MultiVarSplit <- function(vars,
                           split_label = "",
@@ -440,12 +431,13 @@ MultiVarSplit <- function(vars,
   )
 }
 
-
 #' Splits for cutting by values of a numeric variable
-#' @rdname cutsplits
+#'
 #' @inheritParams lyt_args
 #' @inheritParams constr_args
+#'
 #' @exportClass VarStaticCutSplit
+#' @rdname cutsplits
 setClass("VarStaticCutSplit",
   contains = "Split",
   representation(
@@ -461,12 +453,14 @@ setClass("VarStaticCutSplit",
 }
 
 #' Create static cut or static cumulative cut split
+#'
 #' @inheritParams lyt_args
 #' @inheritParams constr_args
+#'
+#' @return A `VarStaticCutSplit`, `CumulativeCutSplit` object for `make_static_cut_split`, or a `VarDynCutSplit`
+#'   object for [VarDynCutSplit()].
+#'
 #' @rdname cutsplits
-#' @return a \code{VarStaticCutSplit}, \code{CumulativeCutSplit} object for
-#'   \code{make_static_cut_split}, or a \code{VarDynCutSplit} object for
-#'   \code{VarDynCutSplit()}
 make_static_cut_split <- function(var,
                                   split_label,
                                   cuts,
@@ -527,23 +521,19 @@ make_static_cut_split <- function(var,
   )
 }
 
-
-
-#' @rdname cutsplits
 #' @exportClass CumulativeCutSplit
-
+#' @rdname cutsplits
 setClass("CumulativeCutSplit", contains = "VarStaticCutSplit")
 
 ## make_static_cut_split with cumulative=TRUE is the constructor
 ## for CumulativeCutSplit
 
-
 ## do we want this to be a CustomizableSplit instead of
 ## taking cut_fun?
 ## cut_funct must take avector and no other arguments
 ## and return a named vector of cut points
-#' @rdname cutsplits
 #' @exportClass VarDynCutSplit
+#' @rdname cutsplits
 setClass("VarDynCutSplit",
   contains = "Split",
   representation(
@@ -552,8 +542,9 @@ setClass("VarDynCutSplit",
     cumulative_cuts = "logical"
   )
 )
-#' @rdname cutsplits
+
 #' @export
+#' @rdname cutsplits
 VarDynCutSplit <- function(var,
                            split_label,
                            cutfun,
@@ -601,8 +592,6 @@ VarDynCutSplit <- function(var,
   )
 }
 
-
-
 ## NB analyze splits can't have content-related things
 setClass("VAnalyzeSplit",
   contains = "Split",
@@ -627,12 +616,13 @@ setClass("AnalyzeColVarSplit",
 #'
 #' @inheritParams lyt_args
 #' @inheritParams constr_args
-#' @param defrowlab character. Default row labels if they are not specified by
-#'   the return value of \code{afun}
-#' @rdname avarspl
-#' @return An \code{AnalyzeVarSplit} object.
+#' @param defrowlab (`character`)\cr default row labels, if not specified by the return value of `afun`.
+#'
+#' @return An `AnalyzeVarSplit` object.
+#'
 #' @author Gabriel Becker
 #' @export
+#' @rdname avarspl
 AnalyzeVarSplit <- function(var,
                             split_label = var,
                             afun,
@@ -682,9 +672,10 @@ AnalyzeVarSplit <- function(var,
 #'
 #' @inheritParams lyt_args
 #' @inheritParams constr_args
-#' @rdname avarspl
+#'
 #' @author Gabriel Becker
 #' @export
+#' @rdname avarspl
 AnalyzeColVarSplit <- function(afun,
                                defrowlab = "",
                                cfun = NULL,
@@ -726,7 +717,6 @@ setClass("CompoundSplit",
   validity = function(object) are(object@payload, "Split")
 )
 
-
 setClass("AnalyzeMultiVars", contains = "CompoundSplit")
 
 .repoutlst <- function(x, nv) {
@@ -739,7 +729,6 @@ setClass("AnalyzeMultiVars", contains = "CompoundSplit")
   rep(x, length.out = nv)
 }
 
-
 .uncompound <- function(csplit) {
   if (is(csplit, "list")) {
     return(unlist(lapply(csplit, .uncompound)))
@@ -773,10 +762,12 @@ make_ma_name <- function(spl, pld = spl_payload(spl)) {
   )
 }
 
-#' @rdname avarspl
-#' @param .payload Used internally, not intended to be set by end users.
-#' @return An \code{AnalyzeMultiVars} split object.
+#' @param .payload (`list`)\cr used internally, not intended to be set by end users.
+#'
+#' @return An `AnalyzeMultiVars` split object.
+#'
 #' @export
+#' @rdname avarspl
 AnalyzeMultiVars <- function(var,
                              split_label = "",
                              afun,
@@ -790,10 +781,7 @@ AnalyzeMultiVars <- function(var,
                              split_name = NULL,
                              extra_args = list(),
                              indent_mod = 0L,
-                             child_labels = c(
-                               "default", "topleft", "visible",
-                               "hidden"
-                             ),
+                             child_labels = c("default", "topleft", "visible", "hidden"),
                              child_names = var,
                              cvar = "",
                              section_div = NA_character_) {
@@ -814,6 +802,7 @@ AnalyzeMultiVars <- function(var,
     cformat <- .repoutlst(cformat, nv)
     ##        split_format = .repoutlst(split_format, nv)
     inclNAs <- .repoutlst(inclNAs, nv)
+    section_div_if_multivar <- if (length(var) > 1) NA_character_ else section_div
     pld <- mapply(AnalyzeVarSplit,
       var = var,
       split_name = child_names,
@@ -830,7 +819,7 @@ AnalyzeMultiVars <- function(var,
         label_pos = show_kidlabs,
         split_format = split_format,
         split_na_str = split_na_str,
-        section_div = section_div
+        section_div = section_div_if_multivar
       ), ## rvis),
       SIMPLIFY = FALSE
     )
@@ -887,13 +876,14 @@ AnalyzeMultiVars <- function(var,
   }
   ret
 }
+
 setClass("VarLevWBaselineSplit",
   contains = "VarLevelSplit",
   representation(
     var = "character",
     ref_group_value = "character"
   )
-) # ,
+)
 
 #' @rdname VarLevelSplit
 #' @export
@@ -942,7 +932,6 @@ VarLevWBaselineSplit <- function(var,
   )
 }
 
-
 .chkname <- function(nm) {
   if (is.null(nm)) {
     nm <- ""
@@ -956,16 +945,11 @@ VarLevWBaselineSplit <- function(var,
   nm
 }
 
-
-
-
-###
 ### Tree Position Representation
 ###
 ### Class(es) that represent position with in a
 ### tree as parallel vectors of Split objects and
 ### values chosen at that split, plus labeling info
-
 TreePos <- function(spls = list(),
                     svals = list(),
                     svlabels = character(),
@@ -989,10 +973,8 @@ TreePos <- function(spls = list(),
   )
 }
 
-##
 ## Tree position convenience functions
 ##
-
 make_child_pos <- function(parpos,
                            newspl,
                            newval,
@@ -1016,13 +998,10 @@ make_child_pos <- function(parpos,
   newpos
 }
 
-
-# Virtual Classes for Tree Nodes and Layouts =================================
-###
-### Virtual class hiearchy for the various types of
-### trees in use in the S4 implementation of the TableTree
-### machinery
-###
+## Virtual Classes for Tree Nodes and Layouts =================================
+##
+## Virtual class hiearchy for the various types of trees in use in the S4
+## implementation of the TableTree machinery
 
 ## core basics
 setClass("VNodeInfo",
@@ -1033,15 +1012,18 @@ setClass("VNodeInfo",
     ## label = "character"
   )
 )
+
 setClass("VTree",
   contains = c("VIRTUAL", "VNodeInfo"),
   representation(children = "list")
 )
+
 setClass("VLeaf", contains = c("VIRTUAL", "VNodeInfo"))
 
+## Layout trees =================================
 
-## Layout trees
 # setClass("VLayoutNode", contains= c("VIRTUAL", "VNodeInfo"))
+
 setClass("VLayoutLeaf",
   contains = c("VIRTUAL", "VLeaf"),
   representation(
@@ -1049,6 +1031,7 @@ setClass("VLayoutLeaf",
     label = "character"
   )
 )
+
 setClass("VLayoutTree",
   contains = c("VIRTUAL", "VTree"),
   representation(
@@ -1057,14 +1040,10 @@ setClass("VLayoutTree",
     label = "character"
   )
 )
+
 setClassUnion("VLayoutNode", c("VLayoutLeaf", "VLayoutTree"))
 
-
-
-
-##
-## LayoutAxisTree classes
-##
+## LayoutAxisTree classes =================================
 
 setOldClass("function")
 setOldClass("NULL")
@@ -1086,7 +1065,6 @@ setClass("LayoutAxisLeaf",
   )
 )
 
-
 setClass("LayoutColTree",
   contains = "LayoutAxisTree",
   representation(
@@ -1147,8 +1125,6 @@ LayoutColLeaf <- function(lev = 0L,
   )
 }
 
-
-
 ## Instantiated column info class ==============================================
 ##
 ## This is so we don't need multiple arguments
@@ -1156,8 +1132,10 @@ LayoutColLeaf <- function(lev = 0L,
 ## various aspects of the column layout
 ## once its applied to the data.
 
-#' `InstantiatedColumnInfo`
+#' Instantiated column info
+#'
 #' @inheritParams gen_args
+#'
 #' @exportClass InstantiatedColumnInfo
 #' @rdname cinfo
 setClass(
@@ -1175,20 +1153,21 @@ setClass(
   )
 )
 
-#' @rdname cinfo
-#' @export
-#' @param treelyt `LayoutColTree`.
-#' @param csubs list. List of subsetting expressions
-#' @param extras list. Extra arguments associated with the columns
-#' @param cnts integer. Counts.
-#' @param total_cnt integer(1). Total observations represented across all
-#'   columns.
-#' @param dispcounts logical(1). Should the counts be displayed as header info when
-#'   the associated table is printed.
-#' @param countformat character(1). Format for the counts if they are displayed
-#' @param count_na_str character. NA string to be used when formatting counts. Defaults
+#' @param treelyt (`LayoutColTree`)\cr a `LayoutColTree` object.
+#' @param csubs (`list`)\cr a list of subsetting expressions.
+#' @param extras (`list`)\cr extra arguments associated with the columns.
+#' @param cnts (`integer`)\cr counts.
+#' @param total_cnt (`integer(1)`)\cr total observations represented across all columns.
+#' @param dispcounts (`flag`)\cr whether the counts should be displayed as header info when the associated
+#'   table is printed.
+#' @param countformat (`string`)\cr format for the counts if they are displayed.
+#' @param count_na_str (`character`)\cr string to use in place of missing values when formatting counts. Defaults
 #'   to `""`.
-#' @return an \code{InstantiateadColumnInfo} object.
+#'
+#' @return An `InstantiateadColumnInfo` object.
+#'
+#' @export
+#' @rdname cinfo
 InstantiatedColumnInfo <- function(treelyt = LayoutColTree(),
                                    csubs = list(expression(TRUE)),
                                    extras = list(list()),
@@ -1204,8 +1183,6 @@ InstantiatedColumnInfo <- function(treelyt = LayoutColTree(),
   cnts <- rep(cnts, length.out = nl)
   csubs <- rep(csubs, length.out = nl)
 
-
-
   nleaves <- length(leaves)
   snas <- sum(is.na(cnts))
   if (length(csubs) != nleaves || length(extras) != nleaves || length(cnts) != nleaves) {
@@ -1236,7 +1213,6 @@ InstantiatedColumnInfo <- function(treelyt = LayoutColTree(),
   )
 }
 
-
 ## TableTrees and row classes ==================================================
 ## XXX Rowspans as implemented dont really work
 ## they're aren't attached to the right data structures
@@ -1267,18 +1243,19 @@ setClass("TableRow",
   )
 )
 
-
-
-
-### TableTree Core non-virtual Classes
+## TableTree Core Non-Virtual Classes ==============
+##
 #' Row classes and constructors
-#' @rdname rowclasses
+#'
 #' @inheritParams constr_args
 #' @inheritParams lyt_args
-#' @param vis logical. Should the row be visible (\code{LabelRow} only).
-#' @author Gabriel Becker
+#' @param vis (`flag`)\cr whether the row should be visible (`LabelRow` only).
+#'
 #' @return A formal object representing a table row of the constructed type.
+#'
+#' @author Gabriel Becker
 #' @export
+#' @rdname rowclasses
 LabelRow <- function(lev = 1L,
                      label = "",
                      name = label,
@@ -1304,7 +1281,8 @@ LabelRow <- function(lev = 1L,
   )
 }
 
-#' Row constructors and Classes
+#' Row constructors and classes
+#'
 #' @rdname rowclasses
 #' @exportClass DataRow
 setClass("DataRow",
@@ -1336,12 +1314,10 @@ setClass("LabelRow",
   representation(visible = "logical")
 )
 
-
-
-#' @rdname rowclasses
-#' @param klass Internal detail.
+#' @param klass (`character`)\cr internal detail.
 #'
 #' @export
+#' @rdname rowclasses
 .tablerow <- function(vals = list(),
                       name = "",
                       lev = 1L,
@@ -1389,12 +1365,14 @@ setClass("LabelRow",
   rw
 }
 
-#' @rdname rowclasses
-#' @param \dots passed to shared constructor (\code{.tablerow}).
+#' @param ... additional parameters passed to shared constructor (`.tablerow`).
+#'
 #' @export
+#' @rdname rowclasses
 DataRow <- function(...) .tablerow(..., klass = "DataRow")
-#' @rdname rowclasses
+
 #' @export
+#' @rdname rowclasses
 ContentRow <- function(...) .tablerow(..., klass = "ContentRow")
 
 setClass("VTitleFooter",
@@ -1407,7 +1385,6 @@ setClass("VTitleFooter",
   )
 )
 
-
 setClass("VTableTree",
   contains = c("VIRTUAL", "VTableNodeInfo", "VTree", "VTitleFooter"),
   representation(
@@ -1436,9 +1413,11 @@ etable_validity <- function(object) {
 ## nocov end
 
 #' `TableTree` classes
-#' @exportClass ElementaryTable
-#' @author Gabriel Becker
+#'
 #' @return A formal object representing a populated table.
+#'
+#' @author Gabriel Becker
+#' @exportClass ElementaryTable
 #' @rdname tabclasses
 setClass("ElementaryTable",
   contains = "VTableTree",
@@ -1490,14 +1469,16 @@ setClass("ElementaryTable",
   lst
 }
 
-#' Table Constructors and Classes
+#' Table constructors and classes
+#'
 #' @inheritParams constr_args
 #' @inheritParams gen_args
 #' @inheritParams lyt_args
-#' @param rspans data.frame. Currently stored but otherwise ignored.
-#' @rdname tabclasses
+#' @param rspans (`data.frame`)\cr currently stored but otherwise ignored.
+#'
 #' @author Gabriel Becker
 #' @export
+#' @rdname tabclasses
 ElementaryTable <- function(kids = list(),
                             name = "",
                             lev = 1L,
@@ -1582,10 +1563,11 @@ ttable_validity <- function(object) {
     EmptyColInfo
   }
 }
+
 ## under this model, non-leaf nodes can have a content table where rollup
 ## analyses live
-#' @rdname tabclasses
 #' @exportClass TableTree
+#' @rdname tabclasses
 setClass("TableTree",
   contains = c("VTableTree"),
   representation(
@@ -1595,8 +1577,8 @@ setClass("TableTree",
   validity = ttable_validity
 )
 
-#' @rdname tabclasses
 #' @export
+#' @rdname tabclasses
 TableTree <- function(kids = list(),
                       name = if (!is.na(var)) var else "",
                       cont = EmptyElTable,
@@ -1691,16 +1673,12 @@ TableTree <- function(kids = list(),
   }
 }
 
-
-###
 ### Pre-Data Layout Declaration Classes
 ###
 ### Notably these are NOT represented as trees
 ### because without data we cannot know what the
 ### children should be.
-###
 
-##
 ## Vector (ordered list) of splits.
 ##
 ## This is a vector (ordered list) of splits to be
@@ -1708,9 +1686,7 @@ TableTree <- function(kids = list(),
 ##
 ## For convenience, if this is length 1, it can contain
 ## a pre-existing TableTree/ElementaryTable.
-## This is used for add_existing_table in
-## colby_constructors.R
-##
+## This is used for add_existing_table in colby_constructors.R
 
 setClass("SplitVector",
   contains = "list",
@@ -1745,8 +1721,6 @@ avar_noneorlast <- function(vec) {
   (length(isavar) == 0) || (length(isavar) == 1 && isavar == length(vec))
 }
 
-
-
 setClass("PreDataAxisLayout",
   contains = "list",
   representation(root_split = "ANY"),
@@ -1762,8 +1736,6 @@ setClass("PreDataAxisLayout",
   }
 )
 
-
-
 setClass("PreDataColLayout",
   contains = "PreDataAxisLayout",
   representation(
@@ -1788,7 +1760,6 @@ PreDataColLayout <- function(x = SplitVector(),
   ret
 }
 
-
 PreDataRowLayout <- function(x = SplitVector(),
                              root = RootSplit(),
                              ...,
@@ -1796,9 +1767,6 @@ PreDataRowLayout <- function(x = SplitVector(),
   new("PreDataRowLayout", lst, root_split = root)
 }
 
-
-
-
 setClass("PreDataTableLayouts",
   contains = "VTitleFooter",
   representation(
@@ -1806,6 +1774,7 @@ setClass("PreDataTableLayouts",
     col_layout = "PreDataColLayout",
     top_left = "character",
     header_section_div = "character",
+    top_level_section_div = "character",
     table_inset = "integer"
   )
 )
@@ -1818,6 +1787,7 @@ PreDataTableLayouts <- function(rlayout = PreDataRowLayout(),
                                 main_footer = character(),
                                 prov_footer = character(),
                                 header_section_div = NA_character_,
+                                top_level_section_div = NA_character_,
                                 table_inset = 0L) {
   new("PreDataTableLayouts",
     row_layout = rlayout,
@@ -1828,12 +1798,11 @@ PreDataTableLayouts <- function(rlayout = PreDataRowLayout(),
     main_footer = main_footer,
     provenance_footer = prov_footer,
     header_section_div = header_section_div,
+    top_level_section_div = top_level_section_div,
     table_inset = table_inset
   )
 }
 
-
-
 ## setClass("CellValue", contains = "ValueWrapper",
 ##          representation(format = "FormatSpec",
 ##                         colspan = "integerOrNULL",
@@ -1844,9 +1813,11 @@ setOldClass("CellValue")
 
 #' Length of a Cell value
 #'
+#' @param x (`CellValue`)\cr a `CellValue` object.
+#'
+#' @return Always returns `1L`.
+#'
 #' @exportMethod length
-#' @return Always returns \code{1L}
-#' @param x x.
 setMethod(
   "length", "CellValue",
   function(x) 1L
@@ -1858,7 +1829,6 @@ setClass("RefFootnote", representation(
   symbol = "character"
 ))
 
-
 RefFootnote <- function(note, index = NA_integer_, symbol = NA_character_) {
   if (is(note, "RefFootnote")) {
     return(note)
@@ -1881,16 +1851,15 @@ RefFootnote <- function(note, index = NA_integer_, symbol = NA_character_) {
   new("RefFootnote", value = note, index = index, symbol = symbol)
 }
 
-#' Cell Value constructor
+#' Constructor for Cell Value
 #'
 #' @inheritParams lyt_args
 #' @inheritParams rcell
-#' @param val ANY. value in the cell exactly as it should be passed to a
-#'   formatter or returned when extracted
-#' @return An object representing the value within a single cell within a
-#'   populated table. The underlying structure of this object is an
-#'   implementation detail and should not be relied upon beyond calling
-#'   accessors for the class.
+#' @param val (`ANY`)\cr value in the cell exactly as it should be passed to a formatter or returned when extracted.
+#'
+#' @return An object representing the value within a single cell within a populated table. The underlying structure
+#'   of this object is an implementation detail and should not be relied upon beyond calling accessors for the class.
+#'
 #' @export
 
 ## Class definition
@@ -1930,8 +1899,8 @@ CellValue <- function(val, format = NULL, colspan = 1L, label = NULL,
   ret
 }
 
-
 #' @method print CellValue
+#'
 #' @export
 print.CellValue <- function(x, ...) {
   cat(paste("rcell:", format_rcell(x), "\n"))
@@ -1944,7 +1913,6 @@ print.CellValue <- function(x, ...) {
 #                                row_labels = "characterOrNULL",
 #                                row_formats = "ANY",
 #                                indent_mods = "integerOrNULL"))
-#
 
 setOldClass("RowsVerticalSection")
 RowsVerticalSection <- function(values,
@@ -1984,8 +1952,8 @@ RowsVerticalSection <- function(values,
   )
 }
 
-
 #' @method print RowsVerticalSection
+#'
 #' @export
 print.RowsVerticalSection <- function(x, ...) {
   cat("RowsVerticalSection (in_rows) object print method:\n-------------------",
@@ -2003,8 +1971,7 @@ print.RowsVerticalSection <- function(x, ...) {
   invisible(x)
 }
 
-
-## ## Empty default objects to avoid repeated calls
+#### Empty default objects to avoid repeated calls
 ## EmptyColInfo <- InstantiatedColumnInfo()
 ## EmptyElTable <- ElementaryTable()
 ## EmptyRootSplit <- RootSplit()
