@@ -1,16 +1,16 @@
-#' row
+#' Create an `rtable` row
 #'
 #' @inheritParams compat_args
-#' @param \dots cell values
+#' @param ... cell values.
+#'
+#' @return A row object of the context-appropriate type (label or data).
 #'
-#' @export
-#' @return A row object of the context-appropriate type (label or data)
-#' @family compatibility
 #' @examples
-#'
 #' rrow("ABC", c(1, 2), c(3, 2), format = "xx (xx.%)")
 #' rrow("")
 #'
+#' @family compatibility
+#' @export
 rrow <- function(row.name = "", ..., format = NULL, indent = 0, inset = 0L) {
   vals <- list(...)
   if (is.null(row.name)) {
@@ -37,7 +37,7 @@ rrow <- function(row.name = "", ..., format = NULL, indent = 0, inset = 0L) {
     ## if(is.character(formats) && length(unique(formats)) == 1L && is.null(format))
     ##     format = unique(formats)
     DataRow(
-      val = vals, lev = as.integer(indent), label = row.name,
+      vals = vals, lev = as.integer(indent), label = row.name,
       name = row.name, ## XXX TODO
       cspan = csps,
       format = format,
@@ -46,15 +46,13 @@ rrow <- function(row.name = "", ..., format = NULL, indent = 0, inset = 0L) {
   }
 }
 
-
-#' `rrowl`
+#' Create an `rtable` row from a vector or list of values
 #'
 #' @inheritParams compat_args
-#' @param \dots values in vector/list form
+#' @param ... values in vector/list form.
 #'
 #' @inherit rrow return
-#' @export
-#' @family compatibility
+#'
 #' @examples
 #' rrowl("a", c(1, 2, 3), format = "xx")
 #' rrowl("a", c(1, 2, 3), c(4, 5, 6), format = "xx")
@@ -70,6 +68,9 @@ rrow <- function(row.name = "", ..., format = NULL, indent = 0, inset = 0L) {
 #'
 #' rrowl(row.name = "row 1", c(1, 2), c(3, 4))
 #' rrow(row.name = "row 2", c(1, 2), c(3, 4))
+#'
+#' @family compatibility
+#' @export
 rrowl <- function(row.name, ..., format = NULL, indent = 0, inset = 0L) {
   dots <- list(...)
   args_list <- c(list(
@@ -92,7 +93,6 @@ paste_em_n <- function(lst, n, sep = ".") {
   ret
 }
 
-
 hrows_to_colinfo <- function(rows) {
   nr <- length(rows)
   stopifnot(nr > 0)
@@ -152,41 +152,35 @@ hrows_to_colinfo <- function(rows) {
   ## we will build it up as if it were full nesting and then prune
   ## based on the columns we actually want.
 
-
   fullcolinfo <- manual_cols(.lst = unqvals)
   fullbusiness <- names(collect_leaves(coltree(fullcolinfo)))
   wanted <- paste_em_n(repvals, nr)
   wantcols <- match(wanted, fullbusiness)
   stopifnot(all(!is.na(wantcols)))
 
-
   subset_cols(fullcolinfo, wantcols)
 }
 
-
 #' Create a header
 #'
 #' @inheritParams compat_args
-#' @param \dots row specifications (either as character vectors or the output
-#'   from \code{\link{rrow}} or \code{\link{DataRow}}, \code{\link{LabelRow}},
-#'   etc.
+#' @param ... row specifications, either as character vectors or the output from [rrow()], [DataRow()],
+#'   [LabelRow()], etc.
+#'
+#' @return A `InstantiatedColumnInfo` object.
 #'
-#' @export
-#' @return a \code{InstantiatedColumnInfo} object.
-#' @family compatibility
 #' @examples
-#'
 #' h1 <- rheader(c("A", "B", "C"))
+#' h1
 #'
 #' h2 <- rheader(
 #'   rrow(NULL, rcell("group 1", colspan = 2), rcell("group 2", colspan = 2)),
 #'   rrow(NULL, "A", "B", "A", "B")
 #' )
-#'
-#' h1
-#'
 #' h2
 #'
+#' @family compatibility
+#' @export
 rheader <- function(..., format = "xx", .lst = NULL) {
   if (!is.null(.lst)) {
     args <- .lst
@@ -202,7 +196,6 @@ rheader <- function(..., format = "xx", .lst = NULL) {
   hrows_to_colinfo(rrows)
 }
 
-
 .char_to_hrows <- function(hdr) {
   nlfnd <- grep("\n", hdr, fixed = TRUE)
   if (length(nlfnd) == 0) {
@@ -221,33 +214,26 @@ rheader <- function(..., format = "xx", .lst = NULL) {
   )
 }
 
-
-#' Create a Table
-#'
-#' @rdname rtable
+#' Create a table
 #'
 #' @inheritParams compat_args
 #' @inheritParams gen_args
-#' @param header Information defining the header (column structure) of the table.
-#'   This can be as row objects (legacy), character vectors or a
-#'   \code{InstantiatedColumnInfo} object.
-#' @param \dots Rows to place in the table.
+#' @param header (`TableRow`, `character`, or `InstantiatedColumnInfo`)\cr information defining the header
+#'   (column structure) of the table. This can be as row objects (legacy), character vectors, or an
+#'   `InstantiatedColumnInfo` object.
+#' @param ... rows to place in the table.
 #'
+#' @return A formal table object of the appropriate type (`ElementaryTable` or `TableTree`).
 #'
-#' @export
-#' @return a formal table object of the appropriate type (\code{ElementaryTable}
-#'   or \code{TableTree})
-#' @family compatibility
 #' @examples
-#'
 #' rtable(
 #'   header = LETTERS[1:3],
 #'   rrow("one to three", 1, 2, 3),
 #'   rrow("more stuff", rcell(pi, format = "xx.xx"), "test", "and more")
 #' )
 #'
-#'
 #' # Table with multirow header
+#'
 #' sel <- iris$Species == "setosa"
 #' mtbl <- rtable(
 #'   header = rheader(
@@ -291,8 +277,8 @@ rheader <- function(..., format = "xx", .lst = NULL) {
 #' row.names(tbl)
 #' names(tbl)
 #'
-#'
 #' # Subsetting
+#'
 #' tbl[1, ]
 #' tbl[, 1]
 #'
@@ -303,13 +289,13 @@ rheader <- function(..., format = "xx", .lst = NULL) {
 #' tbl[5, 1]
 #' tbl[5, 2]
 #'
-#' # # Data Structure methods
+#' # Data Structure methods
+#'
 #' dim(tbl)
 #' nrow(tbl)
 #' ncol(tbl)
 #' names(tbl)
 #'
-#'
 #' # Colspans
 #'
 #' tbl2 <- rtable(
@@ -318,9 +304,10 @@ rheader <- function(..., format = "xx", .lst = NULL) {
 #'   rrow("r1", 1, 2, 3, 4, 5),
 #'   rrow("r2", rcell("sp2", colspan = 2), "sp1", rcell("sp2-2", colspan = 2))
 #' )
-#'
 #' tbl2
 #'
+#' @family compatibility
+#' @export
 rtable <- function(header, ..., format = NULL, hsep = default_hsep(),
                    inset = 0L) {
   if (is.character(header)) {
@@ -388,11 +375,14 @@ only_first_annot <- function(all_annots) {
   }
 }
 
-#' @rdname rbind
+#' @param gap `r lifecycle::badge("deprecated")` ignored.
+#' @param check_headers `r lifecycle::badge("deprecated")` ignored.
+#'
 #' @return A formal table object.
+#'
+#' @rdname rbind
+#' @aliases rbind
 #' @export
-#' @param gap deprecated. Ignored.
-#' @param check_headers deprecated. Ignored.
 rbindl_rtables <- function(x, gap = 0, check_headers = TRUE) {
   if (!check_headers) {
     warning("check_headers = FALSE is no longer supported, ignoring.")
@@ -458,7 +448,6 @@ rbindl_rtables <- function(x, gap = 0, check_headers = TRUE) {
     }))
   }
 
-
   TableTree(
     kids = x,
     cinfo = firstcols,
@@ -471,15 +460,13 @@ rbindl_rtables <- function(x, gap = 0, check_headers = TRUE) {
   )
 }
 
-#' `rbind` `TableTree` and related objects
-#' @rdname rbind
-#' @aliases rbind
-#' @exportMethod rbind
-#' @param deparse.level numeric(1). Currently Ignored.
-#' @param \dots ANY. Elements to be stacked.
+#' Row-bind `TableTree` and related objects
+#'
+#' @param deparse.level (`numeric(1)`)\cr currently ignored.
+#' @param ... (`ANY`)\cr elements to be stacked.
 #'
 #' @note
-#' When objects are rbinded, titles and footer information is retained from the first object (if any exists) if all
+#' When objects are row-bound, titles and footer information is retained from the first object (if any exists) if all
 #' other objects have no titles/footers or have identical titles/footers. Otherwise, all titles/footers are removed
 #' and must be set for the bound table via the [main_title()], [subtitles()], [main_footer()], and [prov_footer()]
 #' functions.
@@ -514,6 +501,9 @@ rbindl_rtables <- function(x, gap = 0, check_headers = TRUE) {
 #' rbind(mtbl, mtbl2)
 #' rbind(mtbl, rrow(), mtbl2)
 #' rbind(mtbl, rrow("aaa"), indent(mtbl2))
+#'
+#' @exportMethod rbind
+#' @rdname rbind
 setMethod(
   "rbind", "VTableNodeInfo",
   function(..., deparse.level = 1) {
@@ -521,8 +511,9 @@ setMethod(
   }
 )
 
+#' @param y (`ANY`)\cr second element to be row-bound via `rbind2`.
+#'
 #' @exportMethod rbind2
-#' @param y Second element to be `rbound` via `rbind2`
 #' @rdname int_methods
 setMethod(
   "rbind2", c("VTableNodeInfo", "missing"),
@@ -531,9 +522,10 @@ setMethod(
   }
 )
 
+#' @param x (`VTableNodeInfo`)\cr `TableTree`, `ElementaryTable`, or `TableRow` object.
+#' @param y (`VTableNodeInfo`)\cr `TableTree`, `ElementaryTable`, or `TableRow` object.
+#'
 #' @exportMethod rbind2
-#' @param x `VTableNodeInfo`. `TableTree`, `ElementaryTable` or `TableRow` object.
-#' @param y `VTableNodeInfo`. `TableTree`, `ElementaryTable` or `TableRow` object.
 #' @rdname rbind
 setMethod(
   "rbind2", "VTableNodeInfo",
@@ -542,8 +534,6 @@ setMethod(
   }
 )
 
-
-
 combine_cinfo <- function(..., new_total = NULL) {
   tabs <- list(...)
   chk_cbindable_many(tabs)
@@ -589,11 +579,11 @@ nz_len_els <- function(lst) {
     lst
   }
 }
+
 has_one_unq <- function(x) {
   length(unique(nz_len_els(x))) <= 1
 }
 
-
 classvec <- function(lst, enforce_one = TRUE) {
   if (enforce_one) {
     vapply(lst, class, "")
@@ -659,20 +649,16 @@ chk_cbindable_many <- function(lst) {
   TRUE
 }
 
-
-#' `cbind` two `rtables`
+#' Column-bind two `TableTree` objects
+#'
+#' @param x (`TableTree` or `TableRow`)\cr a table or row object.
+#' @param ... one or more further objects of the same class as `x`.
 #'
-#' @param x A table or row object
-#' @param \dots 1 or more further objects of the same class as \code{x}
 #' @inherit rbindl_rtables return
-#' @export
 #'
 #' @examples
-#'
 #' x <- rtable(c("A", "B"), rrow("row 1", 1, 2), rrow("row 2", 3, 4))
-#'
 #' y <- rtable("C", rrow("row 1", 5), rrow("row 2", 6))
-#'
 #' z <- rtable("D", rrow("row 1", 9), rrow("row 2", 10))
 #'
 #' t1 <- cbind_rtables(x, y)
@@ -684,6 +670,7 @@ chk_cbindable_many <- function(lst) {
 #' col_paths_summary(t1)
 #' col_paths_summary(t2)
 #'
+#' @export
 cbind_rtables <- function(x, ...) {
   lst <- list(...)
   newcinfo <- combine_cinfo(x, ...)
@@ -780,7 +767,6 @@ setMethod(
     )
     names(kids) <- names(tree_children(x))
 
-
     ElementaryTable(
       kids = kids,
       labelrow = recurse_cbindl(tt_labelrow(x),
@@ -796,9 +782,6 @@ setMethod(
   }
 )
 
-
-
-
 .combine_rows <- function(x, cinfo = NULL, .list) {
   stopifnot(are(.list, class(x)))
 
@@ -809,7 +792,6 @@ setMethod(
     stop("Got rows that don't analyze the same variable")
   }
 
-
   xlst <- c(list(x), .list)
 
   ncols <- vapply(xlst, ncol, 1L)
@@ -854,7 +836,7 @@ setMethod(
   ## This is ok because LabelRow is special cased
   constr_fun <- get(class(x), mode = "function")
   constr_fun(
-    val = vals,
+    vals = vals,
     cspan = cspans,
     cinfo = cinfo,
     var = obj_avar(x),
@@ -863,6 +845,7 @@ setMethod(
     label = obj_label(x)
   )
 }
+
 setMethod(
   "recurse_cbindl", c(
     "TableRow",
@@ -884,8 +867,6 @@ setMethod(
   }
 )
 
-
-
 ## we don't care about the following discrepencies:
 ## - ci2  having NA counts when ci1 doesn't
 ## - mismatching display_ccounts values
@@ -945,25 +926,22 @@ chk_compat_cinfos <- function(tt1, tt2) {
 }
 
 
-#' \[DEPRECATED\] insert `rrows` at (before) a specific location
+#' **Deprecated:** Insert `rrow`s at (before) a specific location
 #'
-#' This function is deprecated and will be removed in a future release of
-#' `rtables`. Please use \code{\link{insert_row_at_path}} or
-#' \code{\link{label_at_path}} instead.
-#' @param tbl `rtable`
-#' @param rrow `rrow` to append to `rtable`
-#' @param at position into which to put the `rrow`, defaults to beginning (i.e. 1)
-#' @param ascontent logical. Currently ignored.
+#' This function is deprecated and will be removed in a future release of `rtables`. Please use
+#' [insert_row_at_path()] or [label_at_path()] instead.
 #'
-#' @return A `TableTree` of the same specific class as \code{tbl}
+#' @param tbl (`VTableTree`)\cr a `rtable` object.
+#' @param rrow (`TableRow`)\cr an `rrow` to append to `tbl`.
+#' @param at (`integer(1)`)\cr position into which to put the `rrow`, defaults to beginning (i.e. row 1).
+#' @param ascontent (`flag`)\cr currently ignored.
 #'
-#' @export
+#' @return A `TableTree` of the same specific class as `tbl`.
 #'
-#' @inherit rbindl_rtables return
+#' @note
+#' Label rows (i.e. a row with no data values, only a `row.name`) can only be inserted at positions which do
+#' not already contain a label row when there is a non-trivial nested row structure in `tbl`.
 #'
-#' @note Label rows (i.e. a row with no data values, only a `row.name`) can only be
-#'   inserted at positions which do not already contain a label row when there
-#'   is a non-trivial nested row structure in \code{tbl}
 #' @examples
 #' o <- options(warn = 0)
 #' lyt <- basic_table() %>%
@@ -991,6 +969,8 @@ chk_compat_cinfos <- function(tt1, tt2) {
 #' insert_rrow(tbl2, rrow("new row", 5, 6, 7), at = 3)
 #'
 #' options(o)
+#'
+#' @export
 insert_rrow <- function(tbl, rrow, at = 1,
                         ascontent = FALSE) {
   .Deprecated("insert_row_at_path or label_at_path(tab)<-", old = "insert_rrow")
@@ -1020,7 +1000,6 @@ insert_rrow <- function(tbl, rrow, at = 1,
   ret
 }
 
-
 .insert_helper <- function(tt, row, at, pos,
                            ascontent = FALSE) {
   islab <- is(row, "LabelRow")
@@ -1035,7 +1014,6 @@ insert_rrow <- function(tbl, rrow, at = 1,
   }
   contnr <- contnr + as.numeric(labelrow_visible(tt))
 
-
   totnr <- nrow(tt)
   endpos <- pos + totnr
   atend <- !islab && endpos == at - 1
@@ -1065,7 +1043,6 @@ insert_rrow <- function(tbl, rrow, at = 1,
     kidnrs <- sapply(kids, nrow)
     cumpos <- pos + cumsum(kidnrs)
 
-
     ## data rows go in the end of the
     ## preceding subtable (if applicable)
     ## label rows go in the beginning of
@@ -1111,8 +1088,8 @@ insert_rrow <- function(tbl, rrow, at = 1,
   tt
 }
 
-
 setGeneric("recurse_insert", function(tt, row, at, pos, ascontent = FALSE) standardGeneric("recurse_insert"))
+
 setMethod(
   "recurse_insert", "TableTree",
   function(tt, row, at, pos, ascontent = FALSE) {
