@@ -2,9 +2,6 @@
 #' @importMethodsFrom formatters toString matrix_form nlines
 NULL
 
-
-
-
 # toString ----
 
 ## #' @export
@@ -16,15 +13,13 @@ NULL
 ## #' @export
 ## setMethod("print", "ANY", base::print)
 
-
 #' Convert an `rtable` object to a string
 #'
 #' @inheritParams formatters::toString
 #' @inheritParams gen_args
 #' @inherit formatters::toString
-#' @exportMethod toString
 #'
-#' @return a string representation of \code{x} as it appears when printed.
+#' @return A string representation of `x` as it appears when printed.
 #'
 #' @examples
 #' library(dplyr)
@@ -42,9 +37,10 @@ NULL
 #' tbl <- build_table(lyt, iris2)
 #'
 #' cat(toString(tbl, col_gap = 3))
+#'
 #' @rdname tostring
-#' @name tostring
-#' @aliases toString,VTableTree-method
+#' @aliases tostring toString,VTableTree-method
+#' @exportMethod toString
 setMethod("toString", "VTableTree", function(x,
                                              widths = NULL,
                                              col_gap = 3,
@@ -66,14 +62,18 @@ setMethod("toString", "VTableTree", function(x,
 
 #' Table shells
 #'
-#' A table shell is a rendering of the table which maintains the structure, but does not
-#' display the values, rather displaying the formatting instructions for each cell.
+#' A table shell is a rendering of the table which maintains the structure, but does not display the values, rather
+#' displaying the formatting instructions for each cell.
 #'
-#' @inheritParams tostring
+#' @inheritParams formatters::toString
 #' @inheritParams gen_args
-#' @return for `table_shell_str` the string representing the table shell, for `table_shell`,
-#' `NULL`, as the function is called for the side effect of printing the shell to the console
-#' @export
+#'
+#' @return
+#' * `table_shell` returns `NULL`, as the function is called for the side effect of printing the shell to the console.
+#' * `table_shell_str` returns the string representing the table shell.
+#'
+#' @seealso [value_formats()] for a matrix of formats for each cell in a table.
+#'
 #' @examples
 #' library(dplyr)
 #'
@@ -89,6 +89,8 @@ setMethod("toString", "VTableTree", function(x,
 #'
 #' tbl <- build_table(lyt, iris2)
 #' table_shell(tbl)
+#'
+#' @export
 table_shell <- function(tt, widths = NULL, col_gap = 3, hsep = default_hsep(),
                         tf_wrap = FALSE, max_width = NULL) {
   cat(table_shell_str(
@@ -132,43 +134,34 @@ table_shell_str <- function(tt, widths = NULL, col_gap = 3, hsep = default_hsep(
   )
 }
 
-
-#' Transform `rtable` to a list of matrices which can be used for outputting
+#' Transform an `rtable` to a list of matrices which can be used for outputting
 #'
 #' Although `rtables` are represented as a tree data structure when outputting the table to ASCII or HTML
-#' it is useful to map the `rtable` to an in between state with the formatted cells in a matrix form.
+#' it is useful to map the `rtable` to an in-between state with the formatted cells in a matrix form.
 #'
 #' @inheritParams gen_args
-#' @param indent_rownames logical(1), if TRUE the column with the row names in
-#'   the `strings` matrix of has indented row names (strings pre-fixed)
-#' @param expand_newlines logical(1). Should the matrix form generated
-#'     expand  rows  whose  values   contain  newlines  into  multiple
-#'     'physical'  rows  (as  they  will  appear  when  rendered  into
-#'     ASCII). Defaults to \code{TRUE}
-#'
-#' @export
+#' @param indent_rownames (`flag`)\cr if `TRUE`, the column with the row names in the `strings` matrix of the output
+#'   has indented row names (strings pre-fixed).
+#' @param expand_newlines (`flag`)\cr whether the matrix form generated should expand rows whose values contain
+#'   newlines into multiple 'physical' rows (as they will appear when rendered into ASCII). Defaults to `TRUE`.
 #'
 #' @details
-#'
-#' The strings in the return object are defined as follows: row labels are those
-#' determined by \code{make_row_df} and cell values are determined using
-#' \code{get_formatted_cells}. (Column labels are calculated using a
-#' non-exported internal function.
+#' The strings in the return object are defined as follows: row labels are those determined by `make_row_df` and cell
+#' values are determined using `get_formatted_cells`. (Column labels are calculated using a non-exported internal
+#' function.
 #'
 #' @return A list with the following elements:
-#' \describe{
-#' \item{strings}{The content, as it should be printed, of the top-left
-#' material, column headers, row labels , and cell values of \code{tt}}
-#' \item{spans}{The column-span information for each print-string in the strings
-#' matrix}
-#' \item{aligns}{The text alignment for each print-string in the strings matrix}
-#' \item{display}{Whether each print-string in the strings matrix should be
-#' printed or not}.
-#' \item{row_info}{the data.frame generated by \code{make_row_df}}
-#' }
+#'   \describe{
+#'     \item{`strings`}{The content, as it should be printed, of the top-left material, column headers, row labels,
+#'       and cell values of `tt`.}
+#'     \item{`spans`}{The column-span information for each print-string in the `strings` matrix.}
+#'     \item{`aligns`}{The text alignment for each print-string in the `strings` matrix.}
+#'     \item{`display`}{Whether each print-string in the strings matrix should be printed.}
+#'     \item{`row_info`}{The `data.frame` generated by `make_row_df`.}
+#'   }
+#'
+#' With an additional `nrow_header` attribute indicating the number of pseudo "rows" that the column structure defines.
 #'
-#' With an additional \code{nrow_header} attribute indicating the number of
-#' pseudo "rows"  the column structure defines.
 #' @examples
 #' library(dplyr)
 #'
@@ -189,6 +182,8 @@ table_shell_str <- function(tt, widths = NULL, col_gap = 3, hsep = default_hsep(
 #' tbl <- build_table(lyt, iris2)
 #'
 #' matrix_form(tbl)
+#'
+#' @export
 setMethod(
   "matrix_form", "VTableTree",
   function(obj,
@@ -239,20 +234,12 @@ setMethod(
     if (disp_ccounts(obj)) {
       hdr_fmt_blank[nrow(hdr_fmt_blank), ] <- c("", rep(colcount_format(obj), ncol(obj)))
     }
-    ## if(disp_ccounts(obj)) {
-    ##     formats <- rbind(matrix("", nrow = nrow(header_content$body) - 1L,
-    ##                             ncol = ncol(header_content$body)),
 
-    ##                      formats_strings)
-    ## } else {
-    ##     formats <- rbind(header_content$body, formats_strings)
-    ## }
     formats <- rbind(hdr_fmt_blank, formats_strings)
 
     spans <- rbind(header_content$span, body_spans)
     row.names(spans) <- NULL
 
-    ## unused??? space <- matrix(rep(0, length(body)), nrow = nrow(body))
     aligns <- rbind(
       matrix(rep("center", length(header_content$body)),
         nrow = nrow(header_content$body)
@@ -262,18 +249,17 @@ setMethod(
 
     aligns[, 1] <- "left" # row names and topleft (still needed for topleft)
 
-    ## if (any(apply(body, c(1, 2), function(x) grepl("\n", x, fixed = TRUE))))
-    ##   stop("no \\n allowed at the moment")
-
-
     nr_header <- nrow(header_content$body)
     if (indent_rownames) {
       body[, 1] <- indent_string(body[, 1], c(rep(0, nr_header), sr$indent),
         incr = indent_size
       )
+      # why also formats?
       formats[, 1] <- indent_string(formats[, 1], c(rep(0, nr_header), sr$indent),
         incr = indent_size
       )
+    } else if (NROW(sr) > 0) {
+      sr$indent <- rep(0, NROW(sr))
     }
 
     col_ref_strs <- matrix(vapply(header_content$footnotes, function(x) {
@@ -296,23 +282,7 @@ setMethod(
       nrow = nrow(body),
       ncol = ncol(body)
     )
-    # Solve \n in titles
-    if (any(grepl("\n", all_titles(obj)))) {
-      if (any(grepl("\n", main_title(obj)))) {
-        tmp_title_vec <- .quick_handle_nl(main_title(obj))
-        main_title(obj) <- tmp_title_vec[1]
-        subtitles(obj) <- c(tmp_title_vec[-1], .quick_handle_nl(subtitles(obj)))
-      } else {
-        subtitles(obj) <- .quick_handle_nl(subtitles(obj))
-      }
-    }
 
-    # Solve \n in footers
-    main_footer(obj) <- .quick_handle_nl(main_footer(obj))
-    prov_footer(obj) <- .quick_handle_nl(prov_footer(obj))
-
-    # xxx \n in page titles are not working atm (I think)
-    # ref_fnotes <- strsplit(get_formatted_fnotes(obj), "\n", fixed = TRUE)
     ref_fnotes <- get_formatted_fnotes(obj) # pagination will not count extra lines coming from here
     pag_titles <- page_titles(obj)
 
@@ -362,8 +332,6 @@ setMethod(
   ret
 }
 
-
-
 format_fnote_ref <- function(fn) {
   if (length(fn) == 0 || (is.list(fn) && all(vapply(fn, function(x) length(x) == 0, TRUE)))) {
     return("")
@@ -382,7 +350,6 @@ format_fnote_ref <- function(fn) {
   }
 }
 
-
 format_fnote_note <- function(fn) {
   if (length(fn) == 0 || (is.list(fn) && all(vapply(fn, function(x) length(x) == 0, TRUE)))) {
     return(character())
@@ -441,8 +408,6 @@ get_formatted_fnotes <- function(tt) {
   lst <- lst[keep]
   unique(vapply(lst, format_fnote_note, ""))
 
-
-
   ##                    , recursive = FALSE)
   ## rlst <- unlist(lapply(rows, row_footnotes))
   ## lst <-
@@ -457,7 +422,6 @@ get_formatted_fnotes <- function(tt) {
   ## allstrs[order(inds)]
 }
 
-
 .do_tbl_h_piece2 <- function(tt) {
   coldf <- make_col_df(tt, visible_only = FALSE)
   remain <- seq_len(nrow(coldf))
@@ -486,6 +450,7 @@ get_formatted_fnotes <- function(tt) {
     }
   )
 }
+
 .pad_end <- function(lst, padto, ncols) {
   curcov <- sum(vapply(lst, cell_cspan, 0L))
   if (curcov == padto) {
@@ -495,7 +460,6 @@ get_formatted_fnotes <- function(tt) {
   c(lst, list(rcell("", colspan = padto - curcov)))
 }
 
-
 .pad_tops <- function(chunks) {
   lens <- vapply(chunks, length, 1L)
   padto <- max(lens)
@@ -548,8 +512,6 @@ get_formatted_fnotes <- function(tt) {
   toret
 }
 
-
-
 .tbl_header_mat <- function(tt) {
   rows <- .do_tbl_h_piece2(tt) ## (clyt)
   cinfo <- col_info(tt)
@@ -574,8 +536,6 @@ get_formatted_fnotes <- function(tt) {
     })
   )
 
-
-
   if (disp_ccounts(cinfo)) {
     counts <- col_counts(cinfo)
     cformat <- colcount_format(cinfo)
@@ -623,19 +583,17 @@ get_formatted_fnotes <- function(tt) {
   )
 }
 
-
-
 # get formatted cells ----
 
-#' get formatted cells
+#' Get formatted cells
 #'
-#' @return the formatted print-strings for all (body) cells in \code{obj}.
-#' @export
 #' @inheritParams gen_args
-#' @param shell logical(1). Should the formats themselves be returned instead of the
-#' values with formats applied. Defaults to \code{FALSE}.
-#' @examples
+#' @param shell (`flag`)\cr whether the formats themselves should be returned instead of the values with formats
+#'   applied. Defaults to `FALSE`.
 #'
+#' @return The formatted print-strings for all (body) cells in `obj`.
+#'
+#' @examples
 #' library(dplyr)
 #'
 #' iris2 <- iris %>%
@@ -650,8 +608,11 @@ get_formatted_fnotes <- function(tt) {
 #'   build_table(iris2)
 #'
 #' get_formatted_cells(tbl)
+#'
+#' @export
 #' @rdname gfc
 setGeneric("get_formatted_cells", function(obj, shell = FALSE) standardGeneric("get_formatted_cells"))
+
 #' @rdname gfc
 setMethod(
   "get_formatted_cells", "TableTree",
@@ -723,9 +684,9 @@ setMethod(
   }
 )
 
-
 #' @rdname gfc
 setGeneric("get_cell_aligns", function(obj) standardGeneric("get_cell_aligns"))
+
 #' @rdname gfc
 setMethod(
   "get_cell_aligns", "TableTree",
@@ -781,21 +742,17 @@ setMethod(
   }
 )
 
-
-
 # utility functions ----
 
-#' from sequence remove numbers where diff == 1
-#'
-#' numbers need to be sorted
-#'
-#' @noRd
+#' From a sorted sequence of numbers, remove numbers where diff == 1
 #'
 #' @examples
 #' remove_consecutive_numbers(x = c(2, 4, 9))
 #' remove_consecutive_numbers(x = c(2, 4, 5, 9))
 #' remove_consecutive_numbers(x = c(2, 4, 5, 6, 9))
 #' remove_consecutive_numbers(x = 4:9)
+#'
+#' @noRd
 remove_consecutive_numbers <- function(x) {
   # actually should be integer
   stopifnot(is.wholenumber(x), is.numeric(x), !is.unsorted(x))
@@ -808,14 +765,13 @@ remove_consecutive_numbers <- function(x) {
   x[c(TRUE, diff(x) != 1)]
 }
 
-
-#' insert an empty string
-#'
-#' @noRd
+#' Insert an empty string
 #'
 #' @examples
 #' empty_string_after(letters[1:5], 2)
 #' empty_string_after(letters[1:5], c(2, 4))
+#'
+#' @noRd
 empty_string_after <- function(x, indices) {
   if (length(indices) > 0) {
     offset <- 0
@@ -827,23 +783,24 @@ empty_string_after <- function(x, indices) {
   x
 }
 
-#' Indent Strings
+#' Indent strings
 #'
 #' Used in rtables to indent row names for the ASCII output.
 #'
-#' @param x a character vector
-#' @param indent a vector of length \code{length(x)} with non-negative integers
-#' @param incr non-negative integer: number of spaces per indent level
-#' @param including_newline boolean: should newlines also be indented
+#' @param x (`character`)\cr a character vector.
+#' @param indent (`numeric`)\cr a vector of non-negative integers of length `length(x)`.
+#' @param incr (`integer(1)`)\cr a non-negative number of spaces per indent level.
+#' @param including_newline (`flag`)\cr whether newlines should also be indented.
+#'
+#' @return `x`, indented with left-padding with `indent * incr` white-spaces.
 #'
-#' @export
-#' @return \code{x} indented by left-padding with \code{indent*incr} white-spaces.
 #' @examples
 #' indent_string("a", 0)
 #' indent_string("a", 1)
 #' indent_string(letters[1:3], 0:2)
 #' indent_string(paste0(letters[1:3], "\n", LETTERS[1:3]), 0:2)
 #'
+#' @export
 indent_string <- function(x, indent = 0, incr = 2, including_newline = TRUE) {
   if (length(x) > 0) {
     indent <- rep_len(indent, length.out = length(x))
@@ -865,7 +822,6 @@ indent_string <- function(x, indent = 0, incr = 2, including_newline = TRUE) {
 ##   paste(na.omit(x), ...)
 ## }
 
-
 ## #' Pad a string and align within string
 ## #'
 ## #' @param x string
@@ -913,26 +869,23 @@ indent_string <- function(x, indent = 0, incr = 2, including_newline = TRUE) {
 ##   strrep(" ", n)
 ## }
 
-
-#' Convert Matrix of Strings into a String with Aligned Columns
+#' Convert matrix of strings into a string with aligned columns
 #'
-#' Note that this function is intended to print simple rectangular
-#' matrices and not rtables.
+#' Note that this function is intended to print simple rectangular matrices and not `rtable`s.
 #'
-#' @param mat a matrix of strings
-#' @param nheader number of header rows
-#' @param colsep string that separates the columns
-#' @param hsep character to build line separator
+#' @param mat (`matrix`)\cr a matrix of strings.
+#' @param nheader (`integer(1)`)\cr number of header rows.
+#' @param colsep (`string`)\cr a string that separates the columns.
+#' @param hsep (`character(1)`)\cr character to build line separator.
 #'
-#' @noRd
-#'
-#' @return a string
+#' @return A string.
 #'
 #' @examples
-#'
 #' mat <- matrix(c("A", "B", "C", "a", "b", "c"), nrow = 2, byrow = TRUE)
 #' cat(mat_as_string(mat))
 #' cat("\n")
+#'
+#' @noRd
 mat_as_string <- function(mat, nheader = 1, colsep = "    ", hsep = default_hsep()) {
   colwidths <- apply(apply(mat, c(1, 2), nchar), 2, max)
 
